@@ -1,5 +1,5 @@
 #!perl
-# $Id: 01_write.pl 315 2008-12-17 21:09:23Z steffenw $
+# $Id: 01_write.pl 378 2009-05-02 06:29:51Z steffenw $
 
 use strict;
 use warnings;
@@ -7,7 +7,7 @@ use warnings;
 our $VERSION = 0;
 
 use Carp qw(croak);
-use DBI ();
+require DBI;
 
 # for test examples only
 our $PATH;
@@ -39,8 +39,6 @@ $dbh->do(<<"EOT");
             reference  VARCHAR,
             obsolete   INTEGER,
             fuzzy      INTEGER,
-            c_format   INTEGER,
-            php_format INTEGER,
             msgid      VARCHAR,
             msgstr     VARCHAR
         )
@@ -74,20 +72,20 @@ EOT
 # declare some data only
 my @data = (
     {
-        original    => 'text1 original',
-        translation => 'text1 translated',
+        msgid  => 'text1 original',
+        msgstr => 'text1 translated',
     },
     {
-        original    => "text2 original\n2nd line of text2",
-        translation => "text2 translated\n2nd line of text2",
+        msgid  => "text2 original\n2nd line of text2",
+        msgstr => "text2 translated\n2nd line of text2",
     },
     {
-        original    => 'text3 original %1',
-        translation => 'text3 translated %1',
+        msgid  => 'text3 original %1',
+        msgstr => 'text3 translated %1',
     },
     {
-        original    => 'text4 original [quant,_1,o_one,o_more,o_nothing]',
-        translation => 'text4 translated [quant,_1,t_one,t_more,t_nothing]',
+        msgid  => 'text4 original [quant,_1,o_one,o_more,o_nothing]',
+        msgstr => 'text4 translated [quant,_1,t_one,t_more,t_nothing]',
     },
 );
 
@@ -95,7 +93,7 @@ my @data = (
 for my $data (@data) {
     $sth->execute(
         $dbh->func(
-            @{$data}{qw(original translation)}, # msgid + msgstr
+            @{$data}{qw(msgid msgstr)},
             'maketext_to_gettext',
         ),
     );
